package com.github.gkutiel.flip.mail;

import org.apache.commons.mail.DefaultAuthenticator;
import org.apache.commons.mail.Email;
import org.apache.commons.mail.EmailException;
import org.apache.commons.mail.HtmlEmail;

class SmtpWithSsl implements EmailProvider {

	private final String smtpServer;
	private final String from;
	private final DefaultAuthenticator authenticator;

	public SmtpWithSsl(final String smtpServer, final String from, final String password) {
		this.smtpServer = smtpServer;
		this.from = from;
		authenticator = new DefaultAuthenticator(from, password);
	}

	@Override
	public void send(final String subject, final String body, final String... to) {
		try {
			final Email email = new HtmlEmail();
			email.setHostName(smtpServer);
			email.setSmtpPort(465);
			email.setAuthenticator(authenticator);
			email.setSSL(true);
			email.setFrom(from);
			email.setSubject(subject);
			email.setCharset("UTF-8");
			email.setMsg(body);
			for (final String t : to)
				email.addTo(t);
			email.send();
		} catch (final EmailException e) {
			throw new RuntimeException(e);
		}
	}
}
